aboutsummaryrefslogtreecommitdiffstats
path: root/src/empathy-call-window.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/empathy-call-window.c')
-rw-r--r--src/empathy-call-window.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/empathy-call-window.c b/src/empathy-call-window.c
index 0d2c57587..343c69244 100644
--- a/src/empathy-call-window.c
+++ b/src/empathy-call-window.c
@@ -861,7 +861,7 @@ display_video_preview (EmpathyCallWindow *self,
if (display)
{
/* Display the preview and hide the self avatar */
DEBUG ("Show video preview");
play_camera (self, TRUE);
@@ -869,8 +869,8 @@ display_video_preview (EmpathyCallWindow *self,
}
else
{
- /* Display the self avatar and hide the preview */
- DEBUG ("Show self avatar");
+ /* Hide the video preview */
+ DEBUG ("Hide video preview");
if (priv->video_preview != NULL)
{
@@ -861,7 +861,7 @@ display_video_preview (EmpathyCallWindow *self,
if (display)
{
- /* Display the preview and hide the self avatar */
+ /* Display the video preview */
DEBUG ("Show video preview");
play_camera (self, TRUE);